searchData={"items":[{"type":"module","title":"LoggerJSON","doc":"A collection of formatters and utilities for JSON-based logging for various cloud tools and platforms.","ref":"LoggerJSON.html"},{"type":"module","title":"Supported formatters - LoggerJSON","doc":"* `LoggerJSON.Formatters.Basic` - a basic JSON formatter that logs messages in a structured format,\ncan be used with any JSON-based logging system, like ElasticSearch, Logstash, etc.\n\n* `LoggerJSON.Formatters.GoogleCloud` - a formatter that logs messages in a structured format that can be\nconsumed by Google Cloud Logger and Google Cloud Error Reporter.\n\n* `LoggerJSON.Formatters.Datadog` - a formatter that logs messages in a structured format that can be consumed\nby Datadog.","ref":"LoggerJSON.html#module-supported-formatters"},{"type":"module","title":"Installation - LoggerJSON","doc":"Add `logger_json` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        # ...\n        {:logger_json, \"~> 6.0\"}\n        # ...\n      ]\n    end\n\nand install it running `mix deps.get`.\n\nThen, enable the formatter in your `config.exs`:\n\n    config :logger, :default_handler,\n      formatter: {LoggerJSON.Formatters.Basic, []}\n\nor during runtime (eg. in your `application.ex`):\n\n    :logger.update_handler_config(:default, :formatter, {Basic, []})","ref":"LoggerJSON.html#module-installation"},{"type":"module","title":"Configuration - LoggerJSON","doc":"Configuration can be set using 2nd element of the tuple of the `:formatter` option in `Logger` configuration.\nFor example in `config.exs`:\n\n    config :logger, :default_handler,\n      formatter: {LoggerJSON.Formatters.GoogleCloud, metadata: :all, project_id: \"logger-101\"}\n\nor during runtime:\n\n    :logger.update_handler_config(:default, :formatter, {Basic, metadata: {:all_except, [:conn]}})","ref":"LoggerJSON.html#module-configuration"},{"type":"module","title":"Shared Options - LoggerJSON","doc":"Some formatters require additional configuration options. Here are the options that are common for each formatter:\n\n  * `:metadata` - a list of metadata keys to include in the log entry. By default, no metadata is included.\n  If `:all`is given, all metadata is included. If `{:all_except, keys}` is given, all metadata except\n  the specified keys is included.\n\n  * `:redactors` - a list of tuples, where first element is the module that implements the `LoggerJSON.Redactor` behaviour,\n  and the second element is the options to pass to the redactor module. By default, no redactors are used.","ref":"LoggerJSON.html#module-shared-options"},{"type":"module","title":"Metadata - LoggerJSON","doc":"You can set some well-known metadata keys to be included in the log entry. The following keys are supported\nfor all formatters:\n\n  * `:conn` - the `Plug.Conn` struct. This is useful when logging HTTP requests and responses,\n  each formatter may use it differently.","ref":"LoggerJSON.html#module-metadata"},{"type":"function","title":"LoggerJSON.configure_log_level!/1","doc":"Changes Logger log level at runtime.\n\nNotice that settings this value below `compile_time_purge_level` would not work,\nbecause Logger calls would be already stripped at compile-time.","ref":"LoggerJSON.html#configure_log_level!/1"},{"type":"function","title":"LoggerJSON.configure_log_level_from_env!/1","doc":"Configures Logger log level at runtime by using value from environment variable.\n\nBy default, 'LOG_LEVEL' environment variable is used.","ref":"LoggerJSON.html#configure_log_level_from_env!/1"},{"type":"module","title":"LoggerJSON.Ecto","doc":"A telemetry handler that logs Ecto query metrics in JSON format.\n\nThis module is not recommended to be used in production, as it can be\ncostly to log every single database query.","ref":"LoggerJSON.Ecto.html"},{"type":"function","title":"LoggerJSON.Ecto.attach/3","doc":"Attaches the telemetry handler to the given event.","ref":"LoggerJSON.Ecto.html#attach/3"},{"type":"function","title":"Available options - LoggerJSON.Ecto.attach/3","doc":"* `:level` - log level which is used to log requests. Defaults to `:info`.","ref":"LoggerJSON.Ecto.html#attach/3-available-options"},{"type":"function","title":"Dynamic log level - LoggerJSON.Ecto.attach/3","doc":"In some cases you may wish to set the log level dynamically\non a per-query basis. To do so, set the `:level` option to\na tuple, `{Mod, Fun, Args}`. The query and map of time measures\nwill be prepended to the provided list of arguments.\n\nWhen invoked, your function must return a\n[`Logger.level()`](`t:Logger.level()/0`) or `false` to\ndisable logging for the request.","ref":"LoggerJSON.Ecto.html#attach/3-dynamic-log-level"},{"type":"function","title":"Examples - LoggerJSON.Ecto.attach/3","doc":"Attaching the telemetry handler to the `MyApp.Repo` events with the `:info` log level:\n\n    LoggerJSON.Ecto.attach(\"logger-json-queries\", [:my_app, :repo, :query], :info)\n\nFor more details on event and handler naming see\n(`Ecto.Repo` documentation)[https://hexdocs.pm/ecto/Ecto.Repo.html#module-telemetry-events].","ref":"LoggerJSON.Ecto.html#attach/3-examples"},{"type":"function","title":"LoggerJSON.Ecto.telemetry_logging_handler/4","doc":"A telemetry handler that logs Ecto query along with it's metrics in a structured format.","ref":"LoggerJSON.Ecto.html#telemetry_logging_handler/4"},{"type":"behaviour","title":"LoggerJSON.Formatter","doc":"","ref":"LoggerJSON.Formatter.html"},{"type":"callback","title":"LoggerJSON.Formatter.format/2","doc":"","ref":"LoggerJSON.Formatter.html#c:format/2"},{"type":"type","title":"LoggerJSON.Formatter.opts/0","doc":"","ref":"LoggerJSON.Formatter.html#t:opts/0"},{"type":"module","title":"LoggerJSON.Formatter.RedactorEncoder","doc":"","ref":"LoggerJSON.Formatter.RedactorEncoder.html"},{"type":"function","title":"LoggerJSON.Formatter.RedactorEncoder.encode/2","doc":"Takes a term and makes sure that it can be encoded by Jason.encode!/1 without errors\nand without leaking sensitive information.","ref":"LoggerJSON.Formatter.RedactorEncoder.html#encode/2"},{"type":"function","title":"Encoding rules - LoggerJSON.Formatter.RedactorEncoder.encode/2","doc":"Type                | Encoding                                            | Redaction\n------------------- | --------------------------------------------------- | --------------\n`boolean()`         | unchanged                                           | unchanged\n`map()`             | unchanged                                           | values are redacted\n`list()`            | unchanged                                           | unchanged\n`tuple()`           | converted to list                                   | unchanged\n`binary()`          | unchanged if printable, otherwise using `inspect/2` | unchanged\n`number()`          | unchanged                                           | unchanged\n`atom()`            | unchanged                                           | unchanged\n`struct()`          | converted to map                                    | values are redacted\n`keyword()`         | converted to map                                    | values are redacted\n`%Jason.Fragment{}` | unchanged                                           | unchanged\neverything else     | using `inspect/2`                                   | unchanged","ref":"LoggerJSON.Formatter.RedactorEncoder.html#encode/2-encoding-rules"},{"type":"type","title":"LoggerJSON.Formatter.RedactorEncoder.redactor/0","doc":"","ref":"LoggerJSON.Formatter.RedactorEncoder.html#t:redactor/0"},{"type":"module","title":"LoggerJSON.Formatters.Basic","doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a JSON format.\n\nFor list of options see \"Shared options\" in `LoggerJSON`.","ref":"LoggerJSON.Formatters.Basic.html"},{"type":"module","title":"Examples - LoggerJSON.Formatters.Basic","doc":"%{\n      \"message\" => \"Hello\",\n      \"metadata\" => %{\"domain\" => [\"elixir\"]},\n      \"severity\" => \"notice\",\n      \"time\" => \"2024-04-11T21:31:01.403Z\"\n    }","ref":"LoggerJSON.Formatters.Basic.html#module-examples"},{"type":"module","title":"LoggerJSON.Formatters.Datadog","doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a structured format that can be consumed by Datadog.\n\nThis formatter adheres to the\n[default standard attribute list](https://docs.datadoghq.com/logs/processing/attributes_naming_convention/#default-standard-attribute-list)\nas much as possible.","ref":"LoggerJSON.Formatters.Datadog.html"},{"type":"module","title":"Formatter Configuration - LoggerJSON.Formatters.Datadog","doc":"The formatter can be configured with the following options:\n\n* `:hostname` (optional) - changes how the `syslog.hostname` is set in logs. By default, it uses `:system` which uses\n  `:inet.gethostname/0` to resolve the value. If you are running in an environment where the hostname is not correct,\n  you can hard code it by setting `hostname` to a string. In places where the hostname is inaccurate but also dynamic\n  (like Kubernetes), you can set `hostname` to `:unset` to exclude it entirely. You'll then be relying on\n  [`dd-agent`](https://docs.datadoghq.com/agent/) to determine the hostname.\n\nFor list of shared options see \"Shared options\" in `LoggerJSON`.","ref":"LoggerJSON.Formatters.Datadog.html#module-formatter-configuration"},{"type":"module","title":"Metadata - LoggerJSON.Formatters.Datadog","doc":"For list of other well-known metadata keys see \"Metadata\" in `LoggerJSON`.","ref":"LoggerJSON.Formatters.Datadog.html#module-metadata"},{"type":"module","title":"Examples - LoggerJSON.Formatters.Datadog","doc":"%{\n      \"domain\" => [\"elixir\"],\n      \"logger\" => %{\n        \"file_name\" => \"/Users/andrew/Projects/os/logger_json/test/formatters/datadog_test.exs\",\n        \"line\" => 44,\n        \"method_name\" => \"Elixir.LoggerJSON.Formatters.DatadogTest.test logs an LogEntry of a given level/1\",\n        \"thread_name\" => \"#PID<0.234.0>\"\n      },\n      \"message\" => \"Hello\",\n      \"syslog\" => %{\n        \"hostname\" => \"MacBook-Pro\",\n        \"severity\" => \"notice\",\n        \"timestamp\" => \"2024-04-11T23:03:39.726Z\"\n      }\n    }","ref":"LoggerJSON.Formatters.Datadog.html#module-examples"},{"type":"module","title":"LoggerJSON.Formatters.GoogleCloud","doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a structured format that can be consumed by Google Cloud Logger.\n\nEven though the log messages on Google Cloud use [LogEntry](https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry)\nformat, not all the fields are available in the structured payload. The fields that are available can be found in the\n[special fields in structured payloads](https://cloud.google.com/logging/docs/agent/configuration#special_fields_in_structured_payloads).","ref":"LoggerJSON.Formatters.GoogleCloud.html"},{"type":"module","title":"Formatter Configuration - LoggerJSON.Formatters.GoogleCloud","doc":"The formatter can be configured with the following options:\n\n* `:project_id` (optional) - the Google Cloud project ID. This is required for correctly logging OpenTelemetry trace and\nspan IDs so that they can be linked to the correct trace in Google Cloud Trace.\n\n* `:service_context` (optional) - a map with the following keys:\n  * `:service` - the name of the service that is logging the message. Default: `node()`.\n  * `:version` - the version of the service that is logging the message.\n\nFor list of shared options see \"Shared options\" in `LoggerJSON`.","ref":"LoggerJSON.Formatters.GoogleCloud.html#module-formatter-configuration"},{"type":"module","title":"Metadata - LoggerJSON.Formatters.GoogleCloud","doc":"You can extend the log entry with some additional metadata:application\n\n  * `user_id`, `identity_id`, `actor_id`, `account_id` (ordered by precedence) - the ID of the user that is performing the action.\n  It will be included along with the error report for Google Cloud Error Reporting;\n\nFor list of other well-known metadata keys see \"Metadata\" in `LoggerJSON`.","ref":"LoggerJSON.Formatters.GoogleCloud.html#module-metadata"},{"type":"module","title":"Examples - LoggerJSON.Formatters.GoogleCloud","doc":"Regular message:\n\n    %{\n      \"logging.googleapis.com/operation\" => %{\"pid\" => \"#PID<0.228.0>\"},\n      \"logging.googleapis.com/sourceLocation\" => %{\n        \"file\" => \"/Users/andrew/Projects/os/logger_json/test/formatters/google_cloud_test.exs\",\n        \"function\" => \"Elixir.LoggerJSON.Formatters.GoogleCloudTest.test logs an LogEntry of a given level/1\",\n        \"line\" => 44\n      },\n      \"message\" => %{\"domain\" => [\"elixir\"], \"message\" => \"Hello\"},\n      \"severity\" => \"NOTICE\",\n      \"time\" => \"2024-04-11T21:32:46.957Z\"\n    }\n\nException message that will be recognized by Google Cloud Error Reporting:\n\n    %{\n      \"httpRequest\" => %{\n        \"protocol\" => \"HTTP/1.1\",\n        \"referer\" => \"http://www.example.com/\",\n        \"remoteIp\" => \"\",\n        \"requestMethod\" => \"PATCH\",\n        \"requestUrl\" => \"http://www.example.com/\",\n        \"status\" => 503,\n        \"userAgent\" => \"Mozilla/5.0\"\n      },\n      \"logging.googleapis.com/operation\" => %{\"pid\" => \"#PID<0.250.0>\"},\n      \"logging.googleapis.com/sourceLocation\" => %{\n        \"file\" => \"/Users/andrew/Projects/os/logger_json/test/formatters/google_cloud_test.exs\",\n        \"function\" => \"Elixir.LoggerJSON.Formatters.GoogleCloudTest.test logs exception http context/1\",\n        \"line\" => 301\n      },\n      \"@type\" => \"type.googleapis.com/google.devtools.clouderrorreporting.v1beta1.ReportedErrorEvent\",\n      \"context\" => %{\n        \"httpRequest\" => %{\n          \"protocol\" => \"HTTP/1.1\",\n          \"referer\" => \"http://www.example.com/\",\n          \"remoteIp\" => \"\",\n          \"requestMethod\" => \"PATCH\",\n          \"requestUrl\" => \"http://www.example.com/\",\n          \"status\" => 503,\n          \"userAgent\" => \"Mozilla/5.0\"\n        },\n        \"reportLocation\" => %{\n          \"filePath\" => \"/Users/andrew/Projects/os/logger_json/test/formatters/google_cloud_test.exs\",\n          \"functionName\" => \"Elixir.LoggerJSON.Formatters.GoogleCloudTest.test logs exception http context/1\",\n          \"lineNumber\" => 301\n        }\n      },\n      \"domain\" => [\"elixir\"],\n      \"message\" => \"Hello\",\n      \"serviceContext\" => %{\"service\" => \"nonode@nohost\"},\n      \"stack_trace\" => \"** (EXIT from #PID<0.250.0>) :foo\",\n      \"severity\" => \"DEBUG\",\n      \"time\" => \"2024-04-11T21:34:53.503Z\"\n    }","ref":"LoggerJSON.Formatters.GoogleCloud.html#module-examples"},{"type":"module","title":"LoggerJSON.Plug","doc":"A telemetry handler that logs request information in JSON format.\n\nThis module is not recommended to be used in production, as it can be\ncostly to log every single database query.","ref":"LoggerJSON.Plug.html"},{"type":"function","title":"LoggerJSON.Plug.attach/3","doc":"Attaches the telemetry handler to the given event.","ref":"LoggerJSON.Plug.html#attach/3"},{"type":"function","title":"Available options - LoggerJSON.Plug.attach/3","doc":"* `:level` - log level which is used to log requests. Defaults to `:info`.","ref":"LoggerJSON.Plug.html#attach/3-available-options"},{"type":"function","title":"Dynamic log level - LoggerJSON.Plug.attach/3","doc":"In some cases you may wish to set the log level dynamically\non a per-query basis. To do so, set the `:level` option to\na tuple, `{Mod, Fun, Args}`. The query and map of time measures\nwill be prepended to the provided list of arguments.\n\nWhen invoked, your function must return a\n[`Logger.level()`](`t:Logger.level()/0`) or `false` to\ndisable logging for the request.","ref":"LoggerJSON.Plug.html#attach/3-dynamic-log-level"},{"type":"function","title":"Examples - LoggerJSON.Plug.attach/3","doc":"Attaching the telemetry handler to the `MyApp.Repo` events with the `:info` log level:\n\n    # in the endpoint\n    plug Plug.Telemetry, event_prefix: [:myapp, :plug]\n\n    # in your application.ex\n    LoggerJSON.Plug.attach(\"logger-json-requests\", [:myapp, :plug, :stop], :info)\n\nTo make plug broadcast those events see [`Plug.Telemetry`](https://hexdocs.pm/plug/Plug.Telemetry.html) documentation.\n\nYou can also attach to the `[:phoenix, :endpoint, :stop]` event to log request latency from Phoenix endpoints:\n\n    LoggerJSON.Plug.attach(\"logger-json-phoenix-requests\", [:phoenix, :endpoint, :stop], :info)","ref":"LoggerJSON.Plug.html#attach/3-examples"},{"type":"function","title":"LoggerJSON.Plug.duration/1","doc":"","ref":"LoggerJSON.Plug.html#duration/1"},{"type":"function","title":"LoggerJSON.Plug.telemetry_logging_handler/4","doc":"A telemetry handler that logs requests in a structured format.","ref":"LoggerJSON.Plug.html#telemetry_logging_handler/4"},{"type":"behaviour","title":"LoggerJSON.Redactor","doc":"This module provides a behaviour which allows to redact sensitive information from logs.\n\n*Note*: redactor will not be applied on `Jason.Fragment` structs. For more information\nabout encoding and redacting see `LoggerJSON.Formatter.RedactorEncoder.encode/2`.","ref":"LoggerJSON.Redactor.html"},{"type":"callback","title":"LoggerJSON.Redactor.redact/3","doc":"Takes a key and a value and returns a redacted value.\n\nThis callback will be applied on key-value pairs, like elements of structs, maps or keyword lists.","ref":"LoggerJSON.Redactor.html#c:redact/3"},{"type":"module","title":"LoggerJSON.Redactors.RedactKeys","doc":"A simple redactor which replace the value of the keys with `\"[REDACTED]\"`.\n\nIt takes list of keys to redact as an argument, eg.:\n```elixir\nconfig :logger, :default_handler,\n  formatter: {LoggerJSON.Formatters.Basic, redactors: [\n    {LoggerJSON.Redactors.RedactKeys, [\"password\"]}\n  ]}\n```\n\nKeep in mind that the key will be converted to binary before sending it to the redactor.","ref":"LoggerJSON.Redactors.RedactKeys.html"},{"type":"function","title":"LoggerJSON.Redactors.RedactKeys.redact/3","doc":"","ref":"LoggerJSON.Redactors.RedactKeys.html#redact/3"},{"type":"extras","title":"License","doc":"The MIT License (MIT)\n\nCopyright (c) 2016 Nebo #15\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# LoggerJSON\n\n[![Build Status](https://travis-ci.org/Nebo15/logger_json.svg?branch=master)](https://travis-ci.org/Nebo15/logger_json)\n[![Module Version](https://img.shields.io/hexpm/v/logger_json.svg)](https://hex.pm/packages/logger_json)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/logger_json/)\n[![Hex Download Total](https://img.shields.io/hexpm/dt/logger_json.svg)](https://hex.pm/packages/logger_json)\n[![License](https://img.shields.io/hexpm/l/logger_json.svg)](https://github.com/Nebo15/logger_json/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/Nebo15/logger_json.svg)](https://github.com/Nebo15/logger_json/commits/master)\n\nA collection of formatters and utilities for JSON-based logging for various cloud tools and platforms.","ref":"readme.html"},{"type":"extras","title":"Supported formatters - Overview","doc":"- `LoggerJSON.Formatters.Basic` - a basic JSON formatter that logs messages in a structured format,\n  can be used with any JSON-based logging system, like ElasticSearch, Logstash, etc.\n\n- `LoggerJSON.Formatters.GoogleCloud` - a formatter that logs messages in a structured format that can be\n  consumed by Google Cloud Logger and Google Cloud Error Reporter.\n\n- `LoggerJSON.Formatters.Datadog` - a formatter that logs messages in a structured format that can be consumed\n  by Datadog.","ref":"readme.html#supported-formatters"},{"type":"extras","title":"Installation - Overview","doc":"Add `logger_json` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    # ...\n    {:logger_json, \"~> 6.0\"}\n    # ...\n  ]\nend\n```\n\nand install it running `mix deps.get`.\n\nThen, enable the formatter in your `config.exs`:\n\n```elixir\nconfig :logger, :default_handler,\n  formatter: {LoggerJSON.Formatters.Basic, []}\n```\n\nor during runtime (eg. in your `application.ex`):\n\n```elixir\n:logger.update_handler_config(:default, :formatter, {Basic, []})\n```\n\nYou might also want to format the log messages when migrations are running:\n\n```elixir\nconfig :domain, MyApp.Repo,\n  # ...\n  start_apps_before_migration: [:logger_json]\n```\n\nAdditionally, you may also be try [redirecting otp reports to Logger](https://hexdocs.pm/logger/Logger.html#module-configuration) (see \"Configuration\" section).","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Overview","doc":"Configuration can be set using 2nd element of the tuple of the `:formatter` option in `Logger` configuration.\nFor example in `config.exs`:\n\n```elixir\nconfig :logger, :default_handler,\n  formatter: {LoggerJSON.Formatters.GoogleCloud, metadata: :all, project_id: \"logger-101\"}\n```\n\nor during runtime:\n\n```elixir\n:logger.update_handler_config(:default, :formatter, {Basic, metadata: {:all_except, [:conn]}})\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Docs - Overview","doc":"The docs can be found at [https://hexdocs.pm/logger_json](https://hexdocs.pm/logger_json).","ref":"readme.html#docs"},{"type":"extras","title":"Examples - Overview","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Basic - Overview","doc":"```json\n{\n  \"message\": \"Hello\",\n  \"metadata\": {\n    \"domain\": [\"elixir\"]\n  },\n  \"severity\": \"notice\",\n  \"time\": \"2024-04-11T21:31:01.403Z\"\n}\n```","ref":"readme.html#basic"},{"type":"extras","title":"Google Cloud Logger - Overview","doc":"Follows the [Google Cloud Logger LogEntry](https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry) format,\nfor more details see [special fields in structured payloads](https://cloud.google.com/logging/docs/agent/configuration#special_fields_in_structured_payloads).\n\n```json\n{\n  \"logging.googleapis.com/trace\": \"projects/my-projectid/traces/0679686673a\",\n  \"logging.googleapis.com/spanId\": \"000000000000004a\",\n  \"logging.googleapis.com/operation\": {\n    \"pid\": \"#PID<0.29081.0>\"\n  },\n  \"logging.googleapis.com/sourceLocation\": {\n    \"file\": \"/Users/andrew/Projects/os/logger_json/test/formatters/google_cloud_test.exs\",\n    \"function\": \"Elixir.LoggerJSON.Formatters.GoogleCloudTest.test logs an LogEntry of a given level/1\",\n    \"line\": 44\n  },\n  \"message\": {\n    \"domain\": [\"elixir\"],\n    \"message\": \"Hello\"\n  },\n  \"severity\": \"NOTICE\",\n  \"time\": \"2024-04-12T15:07:55.020Z\"\n}\n```\n\nand this is how it looks in Google Cloud Logger:\n\n```json\n{\n  \"insertId\": \"1d4hmnafsj7vy1\",\n  \"jsonPayload\": {\n    \"message\": \"Hello\",\n    \"logging.googleapis.com/spanId\": \"000000000000004a\",\n    \"domain\": [\"elixir\"],\n    \"time\": \"2024-04-12T15:07:55.020Z\"\n  },\n  \"resource\": {\n    \"type\": \"gce_instance\",\n    \"labels\": {\n      \"zone\": \"us-east1-d\",\n      \"project_id\": \"firezone-staging\",\n      \"instance_id\": \"3168853301020468373\"\n    }\n  },\n  \"timestamp\": \"2024-04-12T15:07:55.023307594Z\",\n  \"severity\": \"NOTICE\",\n  \"logName\": \"projects/firezone-staging/logs/cos_containers\",\n  \"operation\": {\n    \"id\": \"F8WQ1FsdFAm5ZY0AC1PB\",\n    \"producer\": \"#PID<0.29081.0>\"\n  },\n  \"trace\": \"projects/firezone-staging/traces/bc007e40a2e9edffa23785d8badc43b8\",\n  \"sourceLocation\": {\n    \"file\": \"lib/phoenix/logger.ex\",\n    \"line\": \"231\",\n    \"function\": \"Elixir.Phoenix.Logger.phoenix_endpoint_stop/4\"\n  },\n  \"receiveTimestamp\": \"2024-04-12T15:07:55.678986520Z\"\n}\n```\n\nException that can be sent to Google Cloud Error Reporter:\n\n```json\n{\n  \"httpRequest\": {\n    \"protocol\": \"HTTP/1.1\",\n    \"referer\": \"http://www.example.com/\",\n    \"remoteIp\": \"\",\n    \"requestMethod\": \"PATCH\",\n    \"requestUrl\": \"http://www.example.com/\",\n    \"status\": 503,\n    \"userAgent\": \"Mozilla/5.0\"\n  },\n  \"logging.googleapis.com/operation\": {\n    \"pid\": \"#PID<0.250.0>\"\n  },\n  \"logging.googleapis.com/sourceLocation\": {\n    \"file\": \"/Users/andrew/Projects/os/logger_json/test/formatters/google_cloud_test.exs\",\n    \"function\": \"Elixir.LoggerJSON.Formatters.GoogleCloudTest.test logs exception http context/1\",\n    \"line\": 301\n  },\n  \"@type\": \"type.googleapis.com/google.devtools.clouderrorreporting.v1beta1.ReportedErrorEvent\",\n  \"context\": {\n    \"httpRequest\": {\n      \"protocol\": \"HTTP/1.1\",\n      \"referer\": \"http://www.example.com/\",\n      \"remoteIp\": \"\",\n      \"requestMethod\": \"PATCH\",\n      \"requestUrl\": \"http://www.example.com/\",\n      \"status\": 503,\n      \"userAgent\": \"Mozilla/5.0\"\n    },\n    \"reportLocation\": {\n      \"filePath\": \"/Users/andrew/Projects/os/logger_json/test/formatters/google_cloud_test.exs\",\n      \"functionName\": \"Elixir.LoggerJSON.Formatters.GoogleCloudTest.test logs exception http context/1\",\n      \"lineNumber\": 301\n    }\n  },\n  \"domain\": [\"elixir\"],\n  \"message\": \"Hello\",\n  \"serviceContext\": {\n    \"service\": \"nonode@nohost\"\n  },\n  \"stack_trace\": \"** (EXIT from #PID<0.250.0>) :foo\",\n  \"severity\": \"DEBUG\",\n  \"time\": \"2024-04-11T21:34:53.503Z\"\n}\n```","ref":"readme.html#google-cloud-logger"},{"type":"extras","title":"Datadog - Overview","doc":"Adheres to the [default standard attribute list](https://docs.datadoghq.com/logs/processing/attributes_naming_convention/#default-standard-attribute-list)\nas much as possible.\n\n```json\n{\n  \"domain\": [\"elixir\"],\n  \"http\": {\n    \"method\": \"GET\",\n    \"referer\": \"http://www.example2.com/\",\n    \"request_id\": null,\n    \"status_code\": 200,\n    \"url\": \"http://www.example.com/\",\n    \"url_details\": {\n      \"host\": \"www.example.com\",\n      \"path\": \"/\",\n      \"port\": 80,\n      \"queryString\": \"\",\n      \"scheme\": \"http\"\n    },\n    \"useragent\": \"Mozilla/5.0\"\n  },\n  \"logger\": {\n    \"file_name\": \"/Users/andrew/Projects/os/logger_json/test/formatters/datadog_test.exs\",\n    \"line\": 239,\n    \"method_name\": \"Elixir.LoggerJSON.Formatters.DatadogTest.test logs http context/1\",\n    \"thread_name\": \"#PID<0.225.0>\"\n  },\n  \"message\": \"Hello\",\n  \"network\": {\n    \"client\": {\n      \"ip\": \"127.0.0.1\"\n    }\n  },\n  \"syslog\": {\n    \"hostname\": \"MacBook-Pro\",\n    \"severity\": \"debug\",\n    \"timestamp\": \"2024-04-11T23:10:47.967Z\"\n  }\n}\n```","ref":"readme.html#datadog"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2016 Nebo #15\n\nReleased under the MIT License, which can be found in [LICENSE.md](./LICENSE.md).","ref":"readme.html#copyright-and-license"}],"producer":{"name":"ex_doc","version":[48,46,51,50,46,50]},"content_type":"text/markdown"}